==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkAssemblyPath.java <==
// java wrapper for vtkAssemblyPath object
//

package vtk;
import vtk.*;

public class vtkAssemblyPath extends vtkCollection
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddNode_2(vtkProp id0,vtkMatrix4x4 id1);
  public void AddNode(vtkProp id0,vtkMatrix4x4 id1)
    { AddNode_2(id0,id1); }

  private native long GetNextNode_3();
  public vtkAssemblyNode GetNextNode() {
    long temp = GetNextNode_3();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFirstNode_4();
  public vtkAssemblyNode GetFirstNode() {
    long temp = GetFirstNode_4();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLastNode_5();
  public vtkAssemblyNode GetLastNode() {
    long temp = GetLastNode_5();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeleteLastNode_6();
  public void DeleteLastNode()
    { DeleteLastNode_6(); }

  private native void ShallowCopy_7(vtkAssemblyPath id0);
  public void ShallowCopy(vtkAssemblyPath id0)
    { ShallowCopy_7(id0); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  public vtkAssemblyPath() { super(); }

  public vtkAssemblyPath(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv7h.pkg.tar.xz: vtk/vtkAssemblyPath.java <==
// java wrapper for vtkAssemblyPath object
//

package vtk;
import vtk.*;

public class vtkAssemblyPath extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddNode_2(vtkProp id0,vtkMatrix4x4 id1);
  public void AddNode(vtkProp id0,vtkMatrix4x4 id1)
    { AddNode_2(id0,id1); }

  private native long GetNextNode_3();
  public vtkAssemblyNode GetNextNode() {
    long temp = GetNextNode_3();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFirstNode_4();
  public vtkAssemblyNode GetFirstNode() {
    long temp = GetFirstNode_4();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLastNode_5();
  public vtkAssemblyNode GetLastNode() {
    long temp = GetLastNode_5();

    if (temp == 0) return null;
    return (vtkAssemblyNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeleteLastNode_6();
  public void DeleteLastNode()
    { DeleteLastNode_6(); }

  private native void ShallowCopy_7(vtkAssemblyPath id0);
  public void ShallowCopy(vtkAssemblyPath id0)
    { ShallowCopy_7(id0); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  public vtkAssemblyPath() { super(); }

  public vtkAssemblyPath(long id) { super(id); }
  public native long   VTKInit();

}
